===
API
===

API documentation for the various genopandas modules/classes.

core
----

frame
~~~~~

.. autoclass:: genopandas.core.frame.GenomicDataFrame
    :members:

.. autoclass:: genopandas.core.frame.GenomicIndexer
    :members:

matrix
~~~~~~

.. autoclass:: genopandas.core.matrix.AnnotatedMatrix
    :members:

.. autoclass:: genopandas.core.matrix.GenomicMatrix
    :members:

tree
~~~~

.. autoclass:: genopandas.core.tree.GenomicIntervalTree
    :members:

ngs
---

cnv
~~~

.. autoclass:: genopandas.ngs.cnv.CnvValueMatrix
    :members:

.. autoclass:: genopandas.ngs.cnv.CnvCallMatrix
    :members:

rna
~~~

.. autoclass:: genopandas.ngs.rna.ExpressionMatrix
    :members:
